#!/bin/bash

#
# packager         : sebastian <zenwalkuser> seb@seb2.dyndns.org
#
# source location  :
# http://heanet.dl.sourceforge.net/sourceforge/stardict/stardict-3.0.1.tar.bz2
# 
# 

_error() {
  echo -e $1
  echo -e "\nSee $soft-install.log for errors"
  exit 1
}

soft='stardict'
softversion='3.0.2'
packageversion='70.2'

arch='i486'
cpu='i686'
makeopts='-j2'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
srcuri="http://heanet.dl.sourceforge.net/sourceforge/stardict/$soft-$softversion.tar.bz2"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

echo "------------------------------------------------"
echo "Build package: $soft $softversion"
echo "------------------------------------------------"

cd $buildir
rm -rf $src
if [ ! -f $srcpkg ]; then
  echo "- Download source..."
  wget --passive --quiet $srcuri || _error "\tDownload failed!"
fi 
echo "- Unpacking source..."
tar -xjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS=$CFLAGS

cd $src
chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

echo "- Configuring package..."
cd $src
#patch -p1 < ../stardict-3.0.1-gcc4.3.3.patch || exit 1
#patch -p0 < ../stardict-3.0.1.gcc44.patch || exit 1

    ./configure --prefix=/usr \
    --sysconfdir=/etc \
    --enable-static \
    --disable-gnome-support \
    --disable-festival \
    --disable-espeak \
    --disable-gucharmap \
    --disable-shared \
    --disable-dictdotcn \
    --disable-updateinfo \
    --disable-schemas-install \
    --localstatedir=/var > ../$soft-install.log

echo "- Compiling package..."
make $makeopts >> ../$soft-install.log 2>&1 || _error "\tCompile failed"
echo "- Install package from temp directory"
make install DESTDIR=$dest >> ../$soft-install.log
mkdir -p $dest/usr/man
cp -af $dest/usr/share/man/* $dest/usr/man
rm -fr $dest/usr/share/man

echo "- Stripped all binaries and gzipping man pages..."
( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

echo "- Copying documentation..."
mkdir -p $dest/usr/doc/$soft-$softversion
cp -af \
  AUTHORS COPYING INSTALL NEWS README ChangeLog $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp -af $dest/usr/share/pixmaps/* $dest/usr/share/icons/hicolor/48x48/apps

#removes icons file extension from desktop file
sed -i 's|stardict.png|stardict|' $dest/usr/share/applications/stardict.desktop

mkdir -p $dest/install
cat > $dest/install/slack-desc <<END
   |-----handy-ruler------------------------------------------------------|
$soft: Stardict - an GTK2 based dictionary tool
$soft:
$soft: 
$soft: Stardict is an open-source dictionary tool
$soft: 
$soft: 
$soft: 
$soft:
$soft: 
$soft:
$soft: 
END

mkdir -p $dest/usr/src/$soft-$softversion
#( cd $buildir
#cp -a build-$soft.sh *.patch $dest/usr/src/$soft-$softversion/
#)

( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

#
# place stuff in doinst.sh
#
cat << "EOF" > $dest/install/doinst.sh
if [ -x usr/bin/scrollkeeper-update ]; then
        usr/bin/scrollkeeper-update > /dev/null 2>&1
	fi
EOF


# redundant scrollkeeper
if [ -d $dest/var/scrollkeeper ]; then
		rm -r $dest/var/scrollkeeper
	fi
if [ -d $dest/var/lib/scrollkeeper ]; then
		rm -r $dest/var/lib/scrollkeeper
	fi

cd $dest

# creating package
echo "- Creating $soft package..."
makepkg -l y -c y $dest.txz > /dev/null 2>&1
cd $buildir
md5sum $package.txz > $dest.md5

echo "- Deleting temporary directory's..."
rm -rf $src
rm -rf $dest

echo "Package created complete."
exit 0
